package org.gcube.portlets.user.wsmail.client;

import org.gcube.portlets.user.wsmail.client.forms.MailForm;

import com.google.gwt.core.client.EntryPoint;

/**
 * Entry point classes define <code>onModuleLoad()</code>.
 */
public class WsMail_Widget implements EntryPoint {
	/**
	 * This is the entry point method.
	 */
	public void onModuleLoad() {
		//show();	
	}
	/**
	 * 
	 */
	public void show() {
		new MailForm();
	}
}
